==> elo-grep-1.0.7.tgz: package/index.js <==
#! /usr/bin/env node

// Dependencies
const chalk   = require('chalk');
const prompt  = require('prompt');
const exec    = require('child_process').exec;
const path    = require('path');
const fs      = require('fs');
const program = require('commander');
const pkg     = require('./package.json');

// Main Variables
const location = process.cwd();
const repo     = "https://github.com/tiy-academics/codex/tree/master/content"

// Ensure we are in the root of the codex
let inCodex = fs.existsSync('.catalog.config.yml');
if (!inCodex) {
  oops('Sorry, this can only be run from the root of the Codex.');
  oops(`It looks like you are currently in ${location}`);
  return;
}

// Setup Program
program
  .version(pkg.version)
  .option('-g, --github', 'Opens ELO on GitHub')
  .option('-a, --atom', 'Opens ELO in Atom')
  .option('-s, --sublime', 'Opens ELO in Sublime Text')
  .option('-c, --code', 'Opens ELO in VS Code')
  .option('-o, --other <editor>', 'Opens ELO in specified editor')
  .parse(process.argv);


// Start a prompt
let message = chalk.green('Which learning objective are you looking for?');

prompt.start();
prompt.get([message], function (err, result) {
  let elo = result[message];
  let script = `grep -lr --include \*.objective.config.yml "${elo}" ${location}/*`;
  // Use standard grep - most node packages are meh...
  exec(script, (error, stdout, stderr) => {
      if (error !== null) {
        oops('Sorry, this objective could not be found. Please enter the FULL text when searching.');
      } else {
        displayElo(stdout);
      }
  });
});

// Open the ELO in either GitHub or Editor
function displayElo (filename) {
  let parentDir = path.dirname(filename);

  if (program.github) openGH(parentDir)
  if (program.atom) openEditor('atom', parentDir)
  if (program.sublime) openEditor('subl', parentDir)
  if (program.code) openEditor('code', parentDir)
  if (program.other) openEditor(program.other, parentDir)

  // Set sublime as the default
  openEditor('subl', parentDir);
}

// Opens in editor
function openEditor (editor, dir) {
  return exec(`${editor} ${dir}`, (error, stdout, stderr) => {
    if (error !== null) {
      oops(`ERROR: ${stderr}`);
      oops('This likely means that the editor you chose is not installed.');
    } else {
      console.log(chalk.green(`Opening Path: ${dir}`));
    }
  });
}

// Builds the repo path and opens github.com
function openGH (dir) {
  let regex = /.*\/content(.*)/;
  let ghPath = regex.exec(dir);
  return exec(`open ${repo}${ghPath[1]}`);
}

// Used to color & output error messages
function oops (txt) {
  console.log(chalk.red(txt));
}

==> elo-grep-1.0.9.tgz: package/index.js <==
#! /usr/bin/env node

// Dependencies
const chalk   = require('chalk');
const prompt  = require('prompt');
const exec    = require('child_process').exec;
const path    = require('path');
const fs      = require('fs');
const program = require('commander');
const pkg     = require('./package.json');

// Main Variables
const location = process.cwd();
const repo     = "https://github.com/tiy-academics/codex/tree/master/content"
const editor   = process.env.ELO_EDITOR;

// Ensure we are in the root of the codex
let inCodex = fs.existsSync('.catalog.config.yml');
if (!inCodex) {
  oops('Sorry, this can only be run from the root of the Codex.');
  oops(`It looks like you are currently in ${location}`);
  return;
}

// Setup Program
program
  .version(pkg.version)
  .option('-g, --github', 'Opens ELO on GitHub')
  .option('-a, --atom', 'Opens ELO in Atom')
  .option('-s, --sublime', 'Opens ELO in Sublime Text')
  .option('-c, --code', 'Opens ELO in VS Code')
  .option('-o, --other <editor>', 'Opens ELO in specified editor')
  .parse(process.argv);


// Start a prompt
let message = chalk.green('Which learning objective are you looking for?');

prompt.start();
prompt.get([message], function (err, result) {
  let elo = result[message];
  let script = `grep -lr --include \*.objective.config.yml "${elo}" ${location}/*`;
  // Use standard grep - most node packages are meh...
  exec(script, (error, stdout, stderr) => {
      if (error !== null) {
        oops('Sorry, this objective could not be found. Please enter the FULL text when searching.');
      } else {
        displayElo(stdout);
      }
  });
});

// Open the ELO in either GitHub or Editor
function displayElo (filename) {
  let parentDir = path.dirname(filename);

  // Editor is set & no flags passed, open in default
  if (editor !== undefined && process.argv[2] === undefined) {
    openEditor(editor, parentDir)
  }

  if (program.github) openGH(parentDir)
  if (program.atom) openEditor('atom', parentDir)
  if (program.sublime) openEditor('subl', parentDir)
  if (program.code) openEditor('code', parentDir)
  if (program.other) openEditor(program.other, parentDir)

}

// Opens in editor
function openEditor (editor, dir) {
  exec(`${editor} ${dir}`, (error, stdout, stderr) => {
    if (error !== null) {
      oops(`ERROR: ${stderr}`);
      oops('This likely means that the editor you chose is not installed.');
    } else {
      console.log(chalk.green(`Opening Path: ${dir}`));
    }
  });
}

// Builds the repo path and opens github.com
function openGH (dir) {
  let regex = /.*\/content(.*)/;
  let ghPath = regex.exec(dir);
  return exec(`open ${repo}${ghPath[1]}`);
}

// Used to color & output error messages
function oops (txt) {
  console.log(chalk.red(txt));
}
